@@ -98,7 +98,7 @@ class PeptideSearch():
         string_index = list(chain.from_iterable(L))
         start_index=list((start))
           
-        sys.stdout.write("step1]\n")
+        sys.stdout.write(" step1..]\n")
         a = np.array(peptide)
         _, idx = np.unique(a, return_index=True)
         lista= a[np.sort(idx)]
@@ -138,7 +138,7 @@ class PeptideSearch():
             peptides= self.read_Peptides()
 
         db=self.FastatoCsv()
-        DBString=db['sequence']
+        DBString=db['sequence'] 
         df=pd.DataFrame()
         NoMatch=set()
         sys.stdout.write("This might take a while for large number of peptides, use ctrl+c if you want to interupt the script \n [Progress:")
@@ -156,24 +156,24 @@ class PeptideSearch():
     
                 common = set(c1) & set(c2)
                 
-                if(len(c1)>0 and len(c2)>0):
+                if(len(c1)>0 and len(c2)>0 and len(common)>0):
                     #check for the same sequence
-                    if(len(common)>0):
-                        idx= common.pop()
-                        geneid = db['geneid'][idx][1:]
-                        s1= db['sequence'][idx].find(str1)
-                        s2= db['sequence'][idx].find(str2)
-                        if s2==(s1+len(str1)+1) or s1==0 or s2==0:
-                            start_ends= s1
-                            dfrelay1 = dfrelay1.append({'Peptide':strp, 'geneid/s':geneid, 'start/s':start_ends, 'ExactMatch/OneMismatch':'OneMismatch'}, ignore_index=True)
-                            df=df.append(dfrelay1,ignore_index=True)
-                    else:
-                        NoMatch.add(strp)
+                    idx= common.pop()
+                    geneid = db['geneid'][idx][1:]
+                    s1= db['sequence'][idx].find(str1)
+                    s2= db['sequence'][idx].find(str2)
+                    if s2==(s1+len(str1)+1) or len(str1)==0 or len(str2)==0:
+                        start_ends= s1
+                        dfrelay1 = dfrelay1.append({'Peptide':strp, 'geneid/s':geneid, 'start/s':start_ends, 'ExactMatch/OneMismatch':'OneMismatch'}, ignore_index=True)
+                        df=df.append(dfrelay1,ignore_index=True)
+                else:
+                    NoMatch.add(strp)
+        
+        NoMatch=list(NoMatch)
+        NoMatch = [x for x in NoMatch if x not in list(df["Peptide"])]
         sys.stdout.write(" Done!]\n")
-                            
 
-
-        return df, list(NoMatch)
+        return df, NoMatch
     
     #Combine Exact match and one mismatch functions
     def MatchFinder(self):
@@ -213,10 +213,10 @@ class PeptideSearch():
         return Result, Index   
                     
 
-#List=["ACH", "K"]
-#p= PeptideSearch("Peptides.txt", "Mtb.H37Rv.faFrame1Direct.txt")
-#df, pList= p.OneMismatch(List)
-# df2, N= p.OneMismatch(List)
-# d, s= PeptideSearch.SequenceSearchs("sl", "abcsm")
+# peptides=["MAMTINYQFGDVDAH", "MHVSFVMAYPEMLAA"] 
+#p= PeptideSearch("Peptides.txt", "test.fa")
+# df, pList9= p.OneMismatch(List)
+# 
+#d, s= PeptideSearch.SequenceSearch("sl", "abcsm")
 
 
